@@ -3,10 +3,22 @@ from __future__ import unicode_literals
 
 from django.db import models
 from django.conf import settings
-from mpesa.commons.models import BaseModel
+import uuid
 
 
 # Create your models here.
+class BaseModel(models.Model):
+    uuid = models.UUIDField(default=uuid.uuid4, editable=False)
+    id = models.AutoField(primary_key=True)
+    created_at = models.DateTimeField(auto_now_add=True)
+    updated_at = models.DateTimeField(auto_now=True)
+    is_active = models.BooleanField(default=True, blank=True)
+    is_deleted = models.BooleanField(default=False, blank=True)
+
+    class Meta:
+        abstract = True
+
+
 class PaymentTransaction(models.Model):
     phone_number = models.CharField(max_length=30)
     amount = models.DecimalField(('amount'), max_digits=6, decimal_places=2, default=0)
